@@ -48,7 +48,7 @@ print()
 print('Now calculating velocities...')
 
 Nqpoints, qpoints_scaled, ks, freqs, eigvecs, distances, Hk = read.read_phonopy(file_eigenvectors, tot_atoms_uc)
-Ruc, R0, masses, masses_for_animation = read.read_SPOSCAR_and_masses(file_initial_conf, n_atom_conventional_cell, n_atom_unit_cell, Masses)                       #rhombo or avg R0
+Scell, Ruc, R0, masses, masses_for_animation = read.read_SPOSCAR_and_masses(file_initial_conf, n_atom_conventional_cell, n_atom_unit_cell, Masses)                       #rhombo or avg R0
 
 Rt = np.loadtxt(file_trajectory)[:,1:]
 Num_timesteps = int(len(Rt[:,0]))
