@@ -401,15 +401,14 @@ def plot_k2(f, data, data_projected, indexes,freqs, max_Z, branches,  freq_res,
     num_dispersions = len(freqs)
     colours = ['black', 'red']
     for l in range(num_dispersions):
-        for j in range(tot_branches):
-            ax2.scatter(kk,freqs[l][:,j], marker='x', c=colours[l])
-        ax2.scatter(kk,freqs[l][:,tot_branches-1],  marker='x',  c=colours[l], label=title[l])
+        for j in (branches):
+            graph, = ax2.scatter(kk,freqs[l][:,j], marker='x', c=colours[l], label=title[l])
     ax2.get_shared_y_axes().join(ax, ax2)
     plt.ylim([f[0], f[-1]])
     plt.xlim([kk[0], kk[-1]])
     
     handles, labels = ax.get_legend_handles_labels()
-    plt.legend(handles=handles, labels=labels)
+    plt.legend(handles=[graph])
     ax.tick_params(axis='both', which='major', labelsize=15, width=2 , length=6, direction='in', top=True, left=True, bottom=True)
     ax2.tick_params(axis='y', which='major', labelsize=15, width=2 , length=6, direction='in')
     plt.rcParams['axes.linewidth'] = 2
