@@ -142,7 +142,7 @@ def read_phonopy(file_eigenvectors, n_atom_unit_cell):
 #    qpoints_scaled = np.array(qpoints_scaled)
 #    freqs = np.array(freqs)
     c = 1.88973 #conversion to Bohrs
-    h = np.array(data['reciprocal_lattice'])*2*np.pi*1/c
+    Hk = np.array(data['reciprocal_lattice'])*2*np.pi*1/c
     distances = []
     qpoints_scaled = []
     dist = 0.0
@@ -160,8 +160,8 @@ def read_phonopy(file_eigenvectors, n_atom_unit_cell):
             this_qpoint_sc = this_element['q-position']
             previous_qpoint_sc =  previous_element['q-position']
             
-            this_qpoint = np.dot(h,this_qpoint_sc)
-            previous_qpoint = np.dot(h,previous_qpoint_sc)
+            this_qpoint = np.dot(Hk,this_qpoint_sc)
+            previous_qpoint = np.dot(Hk,previous_qpoint_sc)
             
             diff = this_qpoint - previous_qpoint
             
@@ -190,8 +190,6 @@ def read_phonopy(file_eigenvectors, n_atom_unit_cell):
     Nqpoints = len(qpoints_scaled[:,0])
 
     
-    c = 1.88973 #conversion to Bohrs
-    Hk = np.array(data['reciprocal_lattice'])*2*np.pi*1/c
     ks = np.dot(Hk,qpoints_scaled.T).T
     # =============================================================================
     return Nqpoints, qpoints_scaled, ks, frequencies, eigvecs, distances, Hk
@@ -207,7 +205,8 @@ def read_SPOSCAR_and_masses(file, n_atom_conventional_cell,n_atom_primitive_cell
 
     N1N2N3 = int(N/tot_atoms_primitive)
     
-    if (conv==1.0):
+    #your default units are Bohrs
+    if (conv==1.0 or conv==1):
         conv_factor = 1.88973
     else:
         conv_factor = 1
@@ -242,7 +241,20 @@ def read_SPOSCAR_and_masses(file, n_atom_conventional_cell,n_atom_primitive_cell
     masses = np.array(repeated_masses).flatten()
     masses_for_animation = np.array(repeated_masses_for_ani).flatten()
     
-    return Ruc, R0, masses, masses_for_animation
+    return h*conv_factor, Ruc, R0, masses, masses_for_animation
+
+#h, Ruc, R0, masses, masses_for_animation = read_SPOSCAR_and_masses('../SPOSCAR_primitive', [1,1], [1,1], [1,1])
+#Cell = h/10
+#a1, a2, a3 = Cell[0,:], Cell[1,:], Cell[2,:]
+#
+#
+#b1 = 2*np.pi * np.cross(a2,a3) / np.dot(a1, np.cross(a2,a3))
+#b2 = 2*np.pi * np.cross(a3,a1) / np.dot(a2, np.cross(a3,a1))
+#b3 = 2*np.pi * np.cross(a1,a2) / np.dot(a3, np.cross(a1,a2))
+#
+#print(b1/2/np.pi)
+#print(b2)
+#print(b3)
 
 def read_path(kinput_scaled, Nqpoints, labels, Hk):
     Nq_input = len(kinput_scaled)
